
#include "DS1825_Defs.h"

scratchpad_t ScratchPad;

static void WriteConfig(char value) {
  Ow_Reset(&GPIOA_BASE, 0);                         // Onewire reset signal
  Ow_Write(&GPIOA_BASE, 0, 0xCC);                   // Issue command SKIP_ROM
  Ow_Write(&GPIOA_BASE, 0, 0x4E);                   // Issue command READ_SCRATCHPAD
  Ow_Write(&GPIOA_BASE, 0, 0);
  Ow_Write(&GPIOA_BASE, 0, 0);
  Ow_Write(&GPIOA_BASE, 0, value);
}

void DS1825_Init(char T_Res) {
char reg_value;
switch (T_Res) {
  case 9:
    reg_value = 0;
    ScratchPad.Resolution = 9;
    break;
  case 10:
    reg_value = 0x20;
    ScratchPad.Resolution = 10;
    break;
  case 11:
    reg_value = 0x40;
    ScratchPad.Resolution = 11;
    break;
  case 12:
    reg_value = 0x60;
    ScratchPad.Resolution = 12;
    break;
  default:
    reg_value = 0;
    ScratchPad.Resolution = 9;
  }
  WriteConfig(reg_value);
}

void DS1825_StartConversion() {
  // Perform temperature reading
  Ow_Reset(&GPIOA_BASE, 0);                         // Onewire reset signal
  Ow_Write(&GPIOA_BASE, 0, 0xCC);                   // Issue command SKIP_ROM
  Ow_Write(&GPIOA_BASE, 0, 0x44);                   // Issue command CONVERT_T
    
switch (ScratchPad.Resolution) {
  case 9:
    delay_ms(94);
    break;
  case 10:
    delay_ms(188);
    break;
  case 11:
    delay_ms(375);
    break;
  case 12:
    delay_ms(750);
    break;
  default:
    delay_ms(750);
  }
}

void DS1825_ReadScratchPad() {
  Ow_Reset(&GPIOA_BASE, 0);                         // Onewire reset signal
  Ow_Write(&GPIOA_BASE, 0, 0xCC);                   // Issue command SKIP_ROM
  Ow_Write(&GPIOA_BASE, 0, 0xBE);                   // Issue command READ_SCRATCHPAD
  ScratchPad.Tl = Ow_Read(&GPIOA_BASE, 0);
  ScratchPad.Th = Ow_Read(&GPIOA_BASE, 0);
  ScratchPad.UserTh = Ow_Read(&GPIOA_BASE, 0);
  ScratchPad.UserTl = Ow_Read(&GPIOA_BASE, 0);
  ScratchPad.Config = Ow_Read(&GPIOA_BASE, 0);
}